@@ -17,6 +17,4 @@ which gnome-autogen.sh || {
     exit 1
 }
 
-test -e $srcdir/ChangeLog || touch $srcdir/ChangeLog
-
-ACLOCAL_FLAGS="$ACLOCAL_FLAGS -I m4" REQUIRED_AUTOMAKE_VERSION=1.9 REQUIRED_MACROS=python.m4 USE_GNOME2_MACROS=1 . gnome-autogen.sh
+. gnome-autogen.sh
